# -*- coding: utf-8 -*-
SecretId = "secretId"
SecretKey = "secretKey"
Token = "token"
RoleArn = "role-arn"
RoleSessionName = "role-session-name"
UseCVMRole = "use-cvm-role"
Region = "region"
Endpoint = "endpoint"
Version = "version"
ServiceVersion = "service_version"
Filter = "filter"
Profile = "profile"
Timeout = "timeout"
Output = "output"
ArrayCount = "arrayCount"
Warnings = "warning"
HttpsProxy = "https-proxy"
GenerateCliSkeleton = "generate-cli-skeleton"
CliInputJson = "cli-input-json"
CliUnfoldArgument = "cli-unfold-argument"
Waiter = "waiter"
WaiterInfo = "waiter_info"

ENV_SECRET_ID = "TENCENTCLOUD_SECRET_ID"
ENV_SECRET_KEY = "TENCENTCLOUD_SECRET_KEY"
ENV_ROLE_ARN = "TENCENTCLOUD_ROLE_ARN"
ENV_ROLE_SESSION_NAME = "TENCENTCLOUD_ROLE_SESSION_NAME"
ENV_REGION = "TENCENTCLOUD_REGION"
ENV_TOKEN = "TENCENTCLOUD_TOKEN"
ENV_TKE_REGION = "TKE_REGION"
ENV_TKE_PROVIDER_ID = "TKE_PROVIDER_ID"
ENV_TKE_IDENTITY_TOKEN_FILE = "TKE_IDENTITY_TOKEN_FILE"
ENV_TKE_ROLE_ARN = "TKE_ROLE_ARN"

Help = "help"
CliVersion = "version"
Detail = "detail"


ACTION_GLOBAL_OPT = [SecretId, SecretKey, Token, RoleArn, RoleSessionName, UseCVMRole, Region, Endpoint, Version,
                     Filter, Profile, Timeout, Output, HttpsProxy, GenerateCliSkeleton, CliInputJson, CliUnfoldArgument, Waiter]



